<?php
/**
 * Admin feature for Custom Meta Box
 *
 * @author 		Themeum
 * @category 	Admin Core
 * @package 	Vocal
 *-------------------------------------------------------------*/


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Registering meta boxes
 * For more information, please visit:
 * @link http://www.deluxeblogtips.com/meta-box/
 */

add_filter( 'rwmb_meta_boxes', 'vocal_register_meta_boxes' );

/**
 * Register meta boxes
 *
 * @return void
 */

function vocal_register_meta_boxes( $meta_boxes )
{

	global $woocommerce;

	$price_category = themeum_cat_lists('price_cat');

	$performers = get_all_posts('performer');

	if($woocommerce) {
		$products 	= get_all_posts('product');
	} else {
		$products  	= array();
	}
	
	/**
	 * Prefix of meta keys (optional)
	 * Use underscore (_) at the beginning to make keys hidden
	 * Alt.: You also can make prefix empty to disable it
	 */
	// Better has an underscore as last sign
	$prefix = 'themeum_';


	$social_media = array(
			'facebook' 		=> 'Facebook',
			'twitter' 		=> 'Twitter',
			'google'		=> 'Google Plus',
			'pinterest' 	=> 'Pinterest',
			'flicker' 		=> 'Flicker',
		);



	
	/**
	 * Register Post Meta for Performer Post Type
	 *
	 * @return array
	 */


	$meta_boxes[] = array(
		'id' 		=> 'performer-post-meta',

		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title' 	=> __( 'Performer Post Settings', 'vocal-event' ),

		// Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
		'pages' 	=> array( 'performer'),

		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context' 	=> 'normal',

		// Order of meta box: high (default), low. Optional.
		'priority' 	=> 'high',

		// Auto save: true, false (default). Optional.
		'autosave' 	=> true,

		// List of meta fields
		'fields' 	=> array(
			array(
				'name'  		=> __( 'Short Description', 'vocal-event' ),
				'id'    		=> "{$prefix}performer_shortdesc",
				'desc'  		=> __( 'Performer Short Description', 'vocal-event' ),
				'type'  		=> 'textarea',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Position', 'vocal-event' ),
				'id'    		=> "{$prefix}performer_position",
				'desc'  		=> __( 'Performer Position', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Website Url', 'vocal-event' ),
				'id'    		=> "{$prefix}performer_website",
				'desc'  		=> __( 'Website Url', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Birthday', 'vocal-event' ),
				'id'    		=> "{$prefix}performer_birthday",
				'desc'  		=> __( 'Date of Birth', 'vocal-event' ),
				'type'  		=> 'date',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'YouTube', 'vocal-event' ),
				'id'    		=> "{$prefix}performer_youtube",
				'desc'  		=> __( 'Youtube Url', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Facebook', 'vocal-event' ),
				'id'    		=> "{$prefix}performer_facebook",
				'desc'  		=> __( 'Facebook Profile Url', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Twitter', 'vocal-event' ),
				'id'    		=> "{$prefix}performer_twitter",
				'desc'  		=> __( 'Twitter Profile Url', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Gplus', 'vocal-event' ),
				'id'    		=> "{$prefix}performer_gplus",
				'desc'  		=> __( 'Google Plus Profile Url', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			)		
		)
	);


	/**
	 * Register Post Meta for Albums Post Type
	 *
	 * @return array
	 */

	$meta_boxes[] = array(
		'id' 		=> 'album-post-meta',

		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title' 	=> __( 'Album Post Settings', 'vocal-event' ),

		// Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
		'pages' 	=> array( 'album'),

		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context' 	=> 'normal',

		// Order of meta box: high (default), low. Optional.
		'priority' 	=> 'high',

		// Auto save: true, false (default). Optional.
		'autosave' 	=> true,

		// List of meta fields
		'fields' 	=> array(

			array(
				'name'          => __( 'Artist Name', 'vocal-event' ),
				'id'            => "{$prefix}artist_name",
				'desc'			=> __( 'Artist Name', 'vocal-event' ),
				'type'          => 'text',
				'std'   		=> ''
			),
			array(
				'name'          => __( 'Genre Name', 'vocal-event' ),
				'id'            => "{$prefix}genre_name",
				'desc'			=> __( 'Genre Name', 'vocal-event' ),
				'type'          => 'text',
				'std'   		=> ''
			),				
				array(
				'name'          => __( 'Production Name', 'vocal-event' ),
				'id'            => "{$prefix}production_name",
				'desc'			=> __( 'Production Name', 'vocal-event' ),
				'type'          => 'text',
				'std'   		=> ''
			),		
			array(
				'name'  		=> __( 'Release Date', 'vocal-event' ),
				'id'    		=> "{$prefix}date",
				'desc'  		=> __( 'Release Date', 'vocal-event' ),
				'type'  		=> 'date',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Album Price', 'vocal-event' ),
				'id'    		=> "{$prefix}album_price",
				'desc'  		=> __( 'Album Price', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),

			//Woocommerce
			array(
				'name'  		=> __( 'WooCommerce Product', 'vocal-event' ),
				'id'    		=> "{$prefix}wc_item_id",
				'desc'  		=> __( 'Select product from Woocommerce', 'vocal-event' ),
				'type'  		=> 'select_advanced',
				'options'		=> $products,
				'placeholder' 	=> __( 'Select an Item', 'vocal-event' ),
				'std'   		=> ''
			),

			array(
				'name'  		=> __( 'Purchase Url', 'vocal-event' ),
				'id'    		=> "{$prefix}album_purchase_url",
				'desc'  		=> __( 'Purchase Url', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),

			array(
				'name'  		=> __( 'Purchase Tag', 'vocal-event' ),
				'id'    		=> "{$prefix}purchase_tag",
				'desc'  		=> __( 'Purchase Tag', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> 'Buy Now'
			),
			array(
				'name'  		=> __( 'Audio Source', 'vocal-event' ),
				'id'    		=> "{$prefix}album_audio_source",
				'type'  		=> 'select',
				'options'  		=> array(
					'soundcloud' => __( 'Soundcloud', 'vocal-event' ),
					'selfhosted' => __( 'Self Hosted', 'vocal-event' ),
				),
				'std'         	=> 'selfhosted',
				'placeholder' => __( 'Select Audio Source', 'vocal-event' ),
			),
			array(
				'name'  		=> __( 'Soundcloud Playlist Url', 'vocal-event' ),
				'id'    		=> "{$prefix}album_soundcloud_url",
				'desc'  		=> __( 'Soundcloud Playlist Url. e.g. https://soundcloud.com/tokyopoliceclub', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Audio File', 'vocal-event' ),
				'id'    		=> "{$prefix}album_mp3",
				'desc'  		=> __( 'Audio File', 'vocal-event' ),
				'type'  		=> 'file_advanced',
				'max_file_uploads' => 20,
				'mime_type' 	=> 'audio'
			)		
		)
	);

	
	/**
	 * Register Post Meta for Event Post Type
	 *
	 * @return array
	 */

	$meta_boxes[] = array(
		'id' 		=> 'price-post-meta',

		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title' 	=> __( 'Pricing', 'vocal-event' ),

		// Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
		'pages' 	=> array( 'price'),

		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context' 	=> 'normal',

		// Order of meta box: high (default), low. Optional.
		'priority' 	=> 'high',

		// Auto save: true, false (default). Optional.
		'autosave' 	=> true,

		// List of meta fields
		'fields' 	=> array(
			array(
				'name'  		=> __( 'Price', 'vocal-event' ),
				'id'    		=> "{$prefix}event_pricing_amount",
				'desc'  		=> __( 'e.g. $100,$250 etc', 'vocal-event' ),
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Pricing Details', 'vocal-event' ),
				'id'    		=> "{$prefix}event_pricing_details",
				'type' 			=> 'wysiwyg',
				'raw'  			=> false,
				'std'  			=> '',
				'options' 		=> array(
								'textarea_rows' 	=> 4,
								'teeny'         	=> true,
								'media_buttons' 	=> false,
								)
			),
			array(
				'name'  		=> __( 'Price Button Link', 'vocal-event' ),
				'id'    		=> "{$prefix}event_pricing_button_link",
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Price Button Text', 'vocal-event' ),
				'id'    		=> "{$prefix}event_pricing_button_txt",
				'type'  		=> 'text',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Featured', 'vocal-event' ),
				'id'    		=> "{$prefix}event_featured_pricing",
				'type'  		=> 'checkbox',
				'std'   		=> ''
			),			
		)
	);


	/**
	 * Register Post Meta for Gallery Post Type
	 *
	 * @return array
	 */

	$meta_boxes[] = array(
		'id' 		=> 'gallery-meta',
		'title' 	=> __( 'Gallery Items', 'vocal-event' ),
		'pages' 	=> array( 'gallery'),
		'context' 	=> 'normal',
		'priority' 	=> 'high',
		'autosave' 	=> true,

		'fields' 	=> array(
			array(
				'name'  		=> __( 'Gallery Items', 'vocal-event' ),
				'id'    		=> "{$prefix}vocal_event_gallery",
				'type'  		=> 'image_advanced',
				'std'   		=> ''
				),		
			)
		);

	$meta_boxes[] = array(
		'id' 		=> 'video-meta',
		'title' 	=> __( 'Video Details', 'vocal-event' ),
		'pages' 	=> array( 'video'),
		'context' 	=> 'normal',
		'priority' 	=> 'high',
		'autosave' 	=> true,

		'fields' 	=> array(
			array(
				'name'  		=> __( 'Video Link', 'vocal-event' ),
				'desc'  		=> __( 'Youtube or vimeo url etc', 'vocal-event' ),
				'id'    		=> "{$prefix}vocal_video_link",
				'type'  		=> 'text',
				'std'   		=> ''
				),		
			)
	);

	/**
	 * Register Post Meta for Event Post Type
	 *
	 * @return array
	 */

	$meta_boxes[] = array(
		'id' 		=> 'event-post-meta',

		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title' 	=> __( 'Event Item Settings', 'vocal-event' ),

		// Post types, accept custom post types as well - DEFAULT is array('post'). Optional.
		'pages' 	=> array( 'event'),

		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context' 	=> 'normal',

		// Order of meta box: high (default), low. Optional.
		'priority' 	=> 'high',

		// Auto save: true, false (default). Optional.
		'autosave' 	=> true,

		// List of meta fields
		'fields' 	=> array(

			array(
				'name'  		=> __( 'Start Date and Time', 'vocal-event' ),
				'id'    		=> "{$prefix}event_start_datetime",
				'desc'  		=> __( 'Event Start Date and Time', 'vocal-event' ),
				'type'  		=> 'datetime',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Event End Date and Time', 'vocal-event' ),
				'id'    		=> "{$prefix}event_end_datetime",
				'desc'  		=> __( 'Event Date and Time', 'vocal-event' ),
				'type'  		=> 'datetime',
				'std'   		=> ''
			),
			array(
				'name'  		=> __( 'Performers', 'vocal-event' ),
				'id'    		=> "{$prefix}event_performers",
				'desc'  		=> '',
				'type'     		=> 'select_advanced',
				'options'  		=> $performers,
				'multiple'    	=> true,
				'placeholder' 	=> __( 'Select Performers', 'vocal-event' ),
			),
			array(
				'name'          => __( 'Find Address', 'vocal-event' ),
				'id'            => "{$prefix}event_location",
				'desc'			=> __( 'Just Write The Address and get map below', 'vocal-event' ),
				'type'          => 'textarea',
				'std'           => __( 'Dhaka, Bangladesh', 'vocal-event' ),
			),
			array(
				'name'  		=> __( 'Location', 'vocal-event' ),
				'id'    		=> "{$prefix}event_location_map",
				'desc'  		=> '',
				'type'  		=> 'map',
				'std'           => '23.709921,90.40714300000002,16',
				'style'         => 'width: 500px; height: 260px;',
				'address_field' => "{$prefix}event_location", 
			),
			array(
				'name'  		=> __( 'Disable Map From Single Page:', 'vocal-event' ),
				'id'    		=> "{$prefix}event_map_trigger",
				'type'  		=> 'checkbox',
				'std'   		=> '1'
			),
			array(
				'name'  		=> __( 'Standard Price', 'vocal-event' ),
				'id'    		=> "{$prefix}event_std_price",
				'desc'  		=> 'Standard Price Amoount',
				'type'  		=> 'text',
				'std'   		=> ''
			),

			array(
				'name'  		=> __( 'Ticket button Label', 'vocal-event' ),
				'id'    		=> "{$prefix}event_btn_ticket",
				'desc'  		=> 'Buy Ticket Button Label',
				'type'  		=> 'text',
				'std'   		=> ''
			),

			array(
				'name'  		=> __( 'Ticket Button Link', 'vocal-event' ),
				'id'    		=> "{$prefix}event_ticket_link",
				'desc'  		=> 'Ticket Button Link',
				'type'  		=> 'text',
				'std'   		=> ''
			),

			array(
				'name'  		=> __( 'Price List', 'vocal-event' ),
				'id'    		=> "{$prefix}event_pricing",
				'desc'  		=> '',
				'type'     		=> 'select_advanced',
				'options'  		=> $price_category,
				'multiple'    	=> false,
				'placeholder' 	=> __( 'Select an Item', 'vocal-event' ),
			),
			array(
				'name'  		=> __( 'Disable Price List Layout', 'vocal-event' ),
				'id'    		=> "{$prefix}event_disable_pricing",
				'desc'  		=> 'Click to disable Price List',
				'type'  		=> 'checkbox',
				'std'   		=> ''
			),
			
		)
	);



	return $meta_boxes;
}

/**
 * Get term list from Taxonomy
 *
 * @return array
 */
 

/**
 * Get list of post from any post type
 *
 * @return array
 */

function get_all_posts($post_type)
{
	$args = array(
			'post_type' => $post_type,  // post type name
			'posts_per_page' => -1,   //-1 for all post
		);

	$posts = get_posts($args);

	$post_list = array();

	if (!empty( $posts ))
	{
		foreach ($posts as $post)
		{
			setup_postdata($post);
			$post_list[$post->post_name] = $post->post_title;
		}
		wp_reset_postdata();
		return $post_list;
	}
	else
	{
		return $post_list;
	}	
}
