<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Admin functions for the price post type
 *
 * @author 		Themeum
 * @category 	Admin
 * @package 	Vocal
 * @version     1.0
 *-------------------------------------------------------------*/

/**
 * Register Post Type price
 *
 * @return void
 */

function themeum_post_type_price()
{
	$labels = array( 
		'name'                	=> _x( 'Prices', 'Prices', 'vocal-event' ),
		'singular_name'       	=> _x( 'Price', 'Price', 'vocal-event' ),
		'menu_name'           	=> __( 'Prices', 'vocal-event' ),
		'parent_item_colon'   	=> __( 'Parent Price:', 'vocal-event' ),
		'all_items'           	=> __( 'All Prices', 'vocal-event' ),
		'view_item'           	=> __( 'View Price', 'vocal-event' ),
		'add_new_item'        	=> __( 'Add New Price', 'vocal-event' ),
		'add_new'             	=> __( 'New Price', 'vocal-event' ),
		'edit_item'           	=> __( 'Edit Price', 'vocal-event' ),
		'update_item'         	=> __( 'Update Price', 'vocal-event' ),
		'search_items'        	=> __( 'Search Price', 'vocal-event' ),
		'not_found'           	=> __( 'No article found', 'vocal-event' ),
		'not_found_in_trash'  	=> __( 'No article found in Trash', 'vocal-event' )
		);

	$args = array(  
		'labels'             	=> $labels,
		'public'             	=> true,
		'publicly_queryable' 	=> true,
		'show_in_menu'       	=> true,
		'show_in_admin_bar'   	=> true,
		'exclude_from_search'	=> false,
		'can_export'          	=> true,
		'has_archive'        	=> true,
		'hierarchical'       	=> false,
		'menu_position'      	=> null,
		'menu_icon'				=> '',
		'supports'           	=> array('title')
		);

	register_post_type('price',$args);

}

add_action('init','themeum_post_type_price');


/**
 * View Message When Updated Price
 *
 * @param array $messages Existing post update messages.
 * @return array
 */

function themeum_update_message_price( $messages )
{
	global $post, $post_ID;

	$message['price'] = array(
		0 => '',
		1 => sprintf( __('Price updated. <a href="%s">View Price</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		2 => __('Custom field updated.', 'vocal-event' ),
		3 => __('Custom field deleted.', 'vocal-event' ),
		4 => __('Price updated.', 'vocal-event' ),
		5 => isset($_GET['revision']) ? sprintf( __('Price restored to revision from %s', 'vocal-event' ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
		6 => sprintf( __('Price published. <a href="%s">View Price</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		7 => __('Price saved.', 'vocal-event' ),
		8 => sprintf( __('Price submitted. <a target="_blank" href="%s">Preview Price</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		9 => sprintf( __('Price scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Price</a>', 'vocal-event' ), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
		10 => sprintf( __('Price draft updated. <a target="_blank" href="%s">Preview Price</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		);

return $message;
}

add_filter( 'post_updated_messages', 'themeum_update_message_price' );


/**
 * Register Price Category Taxonomies
 *
 * @return void
 */

function themeum_register_price_cat_taxonomy()
{
	$labels = array(
		'name'              	=> _x( 'Pricing Categories', 'taxonomy general name', 'vocal-event' ),
		'singular_name'     	=> _x( 'Pricing Category', 'taxonomy singular name', 'vocal-event' ),
		'search_items'      	=> __( 'Search Category', 'vocal-event' ),
		'all_items'         	=> __( 'All Categories', 'vocal-event' ),
		'parent_item'       	=> __( 'Parent Category', 'vocal-event' ),
		'parent_item_colon' 	=> __( 'Parent Category:', 'vocal-event' ),
		'edit_item'         	=> __( 'Edit Category', 'vocal-event' ),
		'update_item'       	=> __( 'Update Category', 'vocal-event' ),
		'add_new_item'      	=> __( 'Add New Category', 'vocal-event' ),
		'new_item_name'     	=> __( 'New Category Name', 'vocal-event' ),
		'menu_name'         	=> __( 'Price Category', 'vocal-event' )
		);

	$args = array(	'hierarchical'      	=> true,
		'labels'            	=> $labels,
		'show_ui'           	=> true,
		'show_admin_column' 	=> true,
		'query_var'         	=> true
		);

	register_taxonomy('price_cat',array( 'price' ),$args);
}

add_action('init','themeum_register_price_cat_taxonomy');
