<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


/**
 * Admin functions for the Event post type
 *
 * @author 		Themeum
 * @category 	Admin
 * @package 	Vocal
 * @version     1.0
 *-------------------------------------------------------------*/

/**
 * Register post type video
 *
 * @return void
 */

function themeum_post_type_video()
{
	$labels = array( 
		'name'                	=> _x( 'Videos', 'Videos', 'vocal-event' ),
		'singular_name'       	=> _x( 'Video', 'Video', 'vocal-event' ),
		'menu_name'           	=> __( 'Videos', 'vocal-event' ),
		'parent_item_colon'   	=> __( 'Parent Video:', 'vocal-event' ),
		'all_items'           	=> __( 'All Videos', 'vocal-event' ),
		'view_item'           	=> __( 'View Video', 'vocal-event' ),
		'add_new_item'        	=> __( 'Add New Video', 'vocal-event' ),
		'add_new'             	=> __( 'New Video', 'vocal-event' ),
		'edit_item'           	=> __( 'Edit Video', 'vocal-event' ),
		'update_item'         	=> __( 'Update Video', 'vocal-event' ),
		'search_items'        	=> __( 'Search Video', 'vocal-event' ),
		'not_found'           	=> __( 'No article found', 'vocal-event' ),
		'not_found_in_trash'  	=> __( 'No article found in Trash', 'vocal-event' )
		);

	$args = array(  
		'labels'             	=> $labels,
		'public'             	=> true,
		'publicly_queryable' 	=> true,
		'show_in_menu'       	=> true,
		'show_in_admin_bar'   	=> true,
		'can_export'          	=> true,
		'has_archive'        	=> true,
		'hierarchical'       	=> false,
		'menu_position'      	=> null,
		'menu_icon'				=> 'dashicons-video-alt2',
		'supports'           	=> array( 'title','editor','thumbnail','comments')
		);

	register_post_type('video',$args);

}

add_action('init','themeum_post_type_video');


/**
 * View Message When Updated Project
 *
 * @param array $messages Existing post update messages.
 * @return array
 */

function themeum_update_message_video( $messages )
{
	global $post, $post_ID;

	$message['video'] = array(
		0 => '',
		1 => sprintf( __('Video updated. <a href="%s">View Video</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		2 => __('Custom field updated.', 'vocal-event' ),
		3 => __('Custom field deleted.', 'vocal-event' ),
		4 => __('Event updated.', 'vocal-event' ),
		5 => isset($_GET['revision']) ? sprintf( __('Video restored to revision from %s', 'vocal-event' ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
		6 => sprintf( __('Video published. <a href="%s">View Video</a>', 'vocal-event' ), esc_url( get_permalink($post_ID) ) ),
		7 => __('Video saved.', 'vocal-event' ),
		8 => sprintf( __('Video submitted. <a target="_blank" href="%s">Preview Video</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		9 => sprintf( __('Video scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Video</a>', 'vocal-event' ), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
		10 => sprintf( __('Video draft updated. <a target="_blank" href="%s">Preview Video</a>', 'vocal-event' ), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
		);

return $message;
}

add_filter( 'post_updated_messages', 'themeum_update_message_video' );


/**
 * Register Video Category Taxonomies
 *
 * @return void
 */

function themeum_register_video_cat_taxonomy()
{
	$labels = array(
		'name'              	=> _x( 'Video Categories', 'taxonomy general name', 'vocal-event' ),
		'singular_name'     	=> _x( 'Video Category', 'taxonomy singular name', 'vocal-event' ),
		'search_items'      	=> __( 'Search Video Category', 'vocal-event' ),
		'all_items'         	=> __( 'All Video Category', 'vocal-event' ),
		'parent_item'       	=> __( 'Video Parent Category', 'vocal-event' ),
		'parent_item_colon' 	=> __( 'Video Parent Category:', 'vocal-event' ),
		'edit_item'         	=> __( 'Edit Video Category', 'vocal-event' ),
		'update_item'       	=> __( 'Update Video Category', 'vocal-event' ),
		'add_new_item'      	=> __( 'Add New Video Category', 'vocal-event' ),
		'new_item_name'     	=> __( 'New Video Category Name', 'vocal-event' ),
		'menu_name'         	=> __( 'Video Category', 'vocal-event' )
		);

	$args = array(	'hierarchical'      	=> true,
		'labels'            	=> $labels,
		'show_ui'           	=> true,
		'show_admin_column' 	=> true,
		'query_var'         	=> true
		);

	register_taxonomy('video-category',array( 'video' ),$args);
}

add_action('init','themeum_register_video_cat_taxonomy');




